@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2006-2007 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2006-2011 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -24,13 +24,11 @@
 #include <pango/pangocairo.h>
 #include <glib/gi18n.h>
 #include <stdlib.h>
+#include <math.h>
 
-#include "gpm-common.h"
 #include "gpm-point-obj.h"
 #include "gpm-graph-widget.h"
 
-#include "egg-debug.h"
-
 G_DEFINE_TYPE (GpmGraphWidget, gpm_graph_widget, GTK_TYPE_DRAWING_AREA);
 #define GPM_GRAPH_WIDGET_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_GRAPH_WIDGET, GpmGraphWidgetPrivate))
 #define GPM_GRAPH_WIDGET_FONT "Sans 8"
@@ -118,7 +116,7 @@ gpm_graph_widget_key_data_add (GpmGraphWidget *graph, guint32 color, const gchar
 
 	g_return_val_if_fail (GPM_IS_GRAPH_WIDGET (graph), FALSE);
 
-	egg_debug ("add to list %s", desc);
+	g_debug ("add to list %s", desc);
 	keyitem = g_new0 (GpmGraphWidgetKeyData, 1);
 
 	keyitem->color = color;
@@ -586,6 +584,20 @@ gpm_graph_widget_draw_labels (GpmGraphWidget *graph, cairo_t *cr)
 	cairo_restore (cr);
 }
 
+/**
+ * gpm_color_to_rgb:
+ * @red: The red value
+ * @green: The green value
+ * @blue: The blue value
+ **/
+static void
+gpm_color_to_rgb (guint32 color, guint8 *red, guint8 *green, guint8 *blue)
+{
+	*red = (color & 0xff0000) / 0x10000;
+	*green = (color & 0x00ff00) / 0x100;
+	*blue = color & 0x0000ff;
+}
+
 /**
  * gpm_graph_widget_get_y_label_max_width:
  * @graph: This class instance
@@ -616,6 +628,60 @@ gpm_graph_widget_get_y_label_max_width (GpmGraphWidget *graph, cairo_t *cr)
 	return biggest;
 }
 
+/**
+ * gpm_round_up:
+ * @value: The input value
+ * @smallest: The smallest increment allowed
+ *
+ * 101, 10	110
+ * 95,  10	100
+ * 0,   10	0
+ * 112, 10	120
+ * 100, 10	100
+ **/
+static gint
+gpm_round_up (gfloat value, gint smallest)
+{
+	gfloat division;
+	if (fabs (value) < 0.01)
+		return 0;
+	if (smallest == 0) {
+		g_warning ("divisor zero");
+		return 0;
+	}
+	division = (gfloat) value / (gfloat) smallest;
+	division = ceilf (division);
+	division *= smallest;
+	return (gint) division;
+}
+
+/**
+ * gpm_round_down:
+ * @value: The input value
+ * @smallest: The smallest increment allowed
+ *
+ * 101, 10	100
+ * 95,  10	90
+ * 0,   10	0
+ * 112, 10	110
+ * 100, 10	100
+ **/
+static gint
+gpm_round_down (gfloat value, gint smallest)
+{
+	gfloat division;
+	if (fabs (value) < 0.01)
+		return 0;
+	if (smallest == 0) {
+		g_warning ("divisor zero");
+		return 0;
+	}
+	division = (gfloat) value / (gfloat) smallest;
+	division = floorf (division);
+	division *= smallest;
+	return (gint) division;
+}
+
 /**
  * gpm_graph_widget_autorange_x:
  * @graph: This class instance
@@ -648,7 +714,7 @@ gpm_graph_widget_autorange_x (GpmGraphWidget *graph)
 
 	/* no data in any array */
 	if (len == 0) {
-		egg_debug ("no data");
+		g_debug ("no data");
 		graph->priv->start_x = 0;
 		graph->priv->stop_x = 10;
 		return;
@@ -665,7 +731,7 @@ gpm_graph_widget_autorange_x (GpmGraphWidget *graph)
 				smallest_x = point->x;
 		}
 	}
-	egg_debug ("Data range is %f<x<%f", smallest_x, biggest_x);
+	g_debug ("Data range is %f<x<%f", smallest_x, biggest_x);
 	/* don't allow no difference */
 	if (biggest_x - smallest_x < 0.0001) {
 		biggest_x++;
@@ -689,10 +755,10 @@ gpm_graph_widget_autorange_x (GpmGraphWidget *graph)
 			rounding_x = 10 * 60;
 	}
 
-	graph->priv->start_x = gpm_precision_round_down (smallest_x, rounding_x);
-	graph->priv->stop_x = gpm_precision_round_up (biggest_x, rounding_x);
+	graph->priv->start_x = gpm_round_down (smallest_x, rounding_x);
+	graph->priv->stop_x = gpm_round_up (biggest_x, rounding_x);
 
-	egg_debug ("Processed(1) range is %i<x<%i",
+	g_debug ("Processed(1) range is %i<x<%i",
 		   graph->priv->start_x, graph->priv->stop_x);
 
 	/* if percentage, and close to the end points, then extend */
@@ -706,7 +772,7 @@ gpm_graph_widget_autorange_x (GpmGraphWidget *graph)
 			graph->priv->start_x = 0;
 	}
 
-	egg_debug ("Processed range is %i<x<%i",
+	g_debug ("Processed range is %i<x<%i",
 		   graph->priv->start_x, graph->priv->stop_x);
 }
 
@@ -742,7 +808,7 @@ gpm_graph_widget_autorange_y (GpmGraphWidget *graph)
 
 	/* no data in any array */
 	if (len == 0) {
-		egg_debug ("no data");
+		g_debug ("no data");
 		graph->priv->start_y = 0;
 		graph->priv->stop_y = 10;
 		return;
@@ -759,7 +825,7 @@ gpm_graph_widget_autorange_y (GpmGraphWidget *graph)
 				smallest_y = point->y;
 		}
 	}
-	egg_debug ("Data range is %f<y<%f", smallest_y, biggest_y);
+	g_debug ("Data range is %f<y<%f", smallest_y, biggest_y);
 	/* don't allow no difference */
 	if (biggest_y - smallest_y < 0.0001) {
 		biggest_y++;
@@ -783,8 +849,8 @@ gpm_graph_widget_autorange_y (GpmGraphWidget *graph)
 			rounding_y = 10 * 60;
 	}
 
-	graph->priv->start_y = gpm_precision_round_down (smallest_y, rounding_y);
-	graph->priv->stop_y = gpm_precision_round_up (biggest_y, rounding_y);
+	graph->priv->start_y = gpm_round_down (smallest_y, rounding_y);
+	graph->priv->stop_y = gpm_round_up (biggest_y, rounding_y);
 
 	/* a factor graph always is centered around zero */
 	if (graph->priv->type_y == GPM_GRAPH_WIDGET_TYPE_FACTOR) {
@@ -794,7 +860,7 @@ gpm_graph_widget_autorange_y (GpmGraphWidget *graph)
 			graph->priv->stop_y = -graph->priv->start_y;
 	}
 
-	egg_debug ("Processed(1) range is %i<y<%i",
+	g_debug ("Processed(1) range is %i<y<%i",
 		   graph->priv->start_y, graph->priv->stop_y);
 
 	if (graph->priv->type_y == GPM_GRAPH_WIDGET_TYPE_PERCENTAGE) {
@@ -807,7 +873,7 @@ gpm_graph_widget_autorange_y (GpmGraphWidget *graph)
 			graph->priv->start_y = 0;
 	}
 
-	egg_debug ("Processed range is %i<y<%i",
+	g_debug ("Processed range is %i<y<%i",
 		   graph->priv->start_y, graph->priv->stop_y);
 }
 
@@ -902,7 +968,7 @@ gpm_graph_widget_draw_line (GpmGraphWidget *graph, cairo_t *cr)
 	guint i, j;
 
 	if (graph->priv->data_list->len == 0) {
-		egg_debug ("no data");
+		g_debug ("no data");
 		return;
 	}
 	cairo_save (cr);
@@ -1004,7 +1070,7 @@ gpm_graph_widget_draw_legend (GpmGraphWidget *graph, gint x, gint y, gint width,
 		keydataitem = (GpmGraphWidgetKeyData *) g_slist_nth_data (graph->priv->key_data, i);
 		if (keydataitem == NULL) {
 			/* this shouldn't ever happen */
-			egg_warning ("keydataitem NULL!");
+			g_warning ("keydataitem NULL!");
 			break;
 		}
 		gpm_graph_widget_draw_legend_line (cr, x + 8, y_count, keydataitem->color);
